@@ -325,7 +325,7 @@ class Test_UDMExtension:
         for line in module_help_text:
             try:
                 cli_name = line.strip().split()[0]
-            except Exception:
+            except IndexError:
                 continue
 
             if cli_name in extended_attributes:
